@@ -11,16 +11,16 @@ router = SlashRouter(tags=["Tieba"])
 TiebaAPIRoot = NetRequest()
 
 
-async def requestClient():
+async def request_client():
     async with TiebaAPIRoot as client:
         yield TiebaEndpoint(client)
 
 
 @router.get("/")
-async def matchAll(
+async def _match_all(
     request: Request,
     type: EndpointsType = EndpointsType.post_detail,
-    endpoint: TiebaEndpoint = Depends(requestClient),
+    endpoint: TiebaEndpoint = Depends(request_client),
 ):
     func: Callable[..., Coroutine] = getattr(endpoint, type)
     return await func(**exclude_params(func, request.query_params))
@@ -31,7 +31,7 @@ async def post_list(
     name: str,
     page: int = 1,
     size: int = 50,
-    endpoint: TiebaEndpoint = Depends(requestClient),
+    endpoint: TiebaEndpoint = Depends(request_client),
 ):
     return await endpoint.post_list(name=name, page=page, size=size)
 
@@ -42,7 +42,7 @@ async def post_detail(
     page: int = 1,
     size: int = 50,
     reversed: bool = False,
-    endpoint: TiebaEndpoint = Depends(requestClient),
+    endpoint: TiebaEndpoint = Depends(request_client),
 ):
     return await endpoint.post_detail(tid=tid, page=page, size=size, reversed=reversed)
 
@@ -53,18 +53,18 @@ async def subpost_detail(
     pid: int,
     page: int = 1,
     size: int = 50,
-    endpoint: TiebaEndpoint = Depends(requestClient),
+    endpoint: TiebaEndpoint = Depends(request_client),
 ):
     return await endpoint.subpost_detail(tid=tid, pid=pid, page=page, size=size)
 
 
 @router.get(EndpointsType.user_profile)
-async def user_profile(uid: int, endpoint: TiebaEndpoint = Depends(requestClient)):
+async def user_profile(uid: int, endpoint: TiebaEndpoint = Depends(request_client)):
     return await endpoint.user_profile(uid=uid)
 
 
 @router.get(EndpointsType.user_subscribed)
 async def user_subscribed(
-    uid: int, page: int = 1, endpoint: TiebaEndpoint = Depends(requestClient)
+    uid: int, page: int = 1, endpoint: TiebaEndpoint = Depends(request_client)
 ):
     return await endpoint.user_subscribed(uid=uid, page=page)
